#
# spec file for package ipmctl
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define abi     5
#define vgit    .1547861714.b7a59da
%define vgit    %{nil}

Name:           ipmctl
VCS: https://src.suse.de/SLFO-pool/ipmctl#c84db14602199d083b8ba3fab30e61d9fca85fdc33db12bfd2735628c0c6004b
Version:        03.00.00.0468
Release:        160000.2.10
Summary:        Utility for managing Intel Optane persistent memory modules
License:        BSD-3-Clause
Group:          System/Management
URL:            https://github.com/intel/ipmctl
%if "%{vgit}" == ""
Source:         https://github.com/intel/ipmctl/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
%else
Source:         %{name}-%{version}%{vgit}.tar.gz
%endif
Source1:        ChangeLog.xz
Source2:        %{name}-rpmlintrc
Patch1:         ipmctl-static-EDK2.patch.xz

Recommends:     logrotate
%if %{defined pythons}
BuildRequires:  %{pythons}
%else
BuildRequires:  python
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libndctl) >= 58.2
BuildRequires:  pkgconfig(systemd)
# required for documentation
BuildRequires:  rubygem(asciidoctor)

# no 'Conflicts' for 'zypper patch'
Obsoletes:      lib%{name}2
# for impctl
Obsoletes:      ixpdimm-cli < 01.00.00.3000
# for (obsoleted) libipmctl2 et.al.
Obsoletes:      ipmctl-data < %{version}
Obsoletes:      ixpdimm-data < 01.00.00.3000
Obsoletes:      ixpdimm_sw < 01.00.00.3000
Obsoletes:      libixpdimm < 01.00.00.3000
Obsoletes:      libixpdimm-cim < 01.00.00.3000
Obsoletes:      libixpdimm-cli < 01.00.00.3000
Obsoletes:      libixpdimm-common < 01.00.00.3000
Obsoletes:      libixpdimm-core < 01.00.00.3000

ExclusiveArch:  x86_64

%description
Utility for managing Intel Optane persistent memory modules (PMem module)
Supports functionality to:
- Discover PMem modules on the platform.
- Provision the platform memory configuration.
- View and update the firmware on PMem modules.
- Configure data-at-rest security on PMem modules.
- Monitor PMem module health.
- Track performance of PMem modules.
- Debug and troubleshoot PMem modules.

%package devel
Summary:        Development packages for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Obsoletes:      ixpdimm-devel < 01.00.00.3000
Obsoletes:      ixpdimm_sw-devel < 01.00.00.3000

%description devel
API for development of Intel Optane persistent memory management utilities.

%prep
%autosetup -p1 -n %{name}-%{version}%{vgit}

perl -pi.00 -e '
  s[(CMAKE_INSTALL_)DATAROOT(DIR\})/ipmctl][${1}SYSCONF${2}];
  s[(INI_INSTALL_FILEPATH "\$\{CMAKE_INSTALL_)DATAROOT(DIR\}")][${1}SYSCONF${2}];
  s[(-DINI_INSTALL_FILEPATH="\$\{INI_INSTALL_FILEPATH\})/ipmctl][${1}];
' CMakeLists.txt
diff -u CMakeLists.txt{.00,} || sleep 4

! grep -lri 'INTEL CONFIDENTIAL' || exit 1

%build
%cmake -DBUILDNUM=%{version} -DCMAKE_INSTALL_PREFIX=/ \
    -DLINUX_PRODUCT_NAME=%{name} \
    -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
    -DCMAKE_INSTALL_BINDIR=%{_bindir} \
    -DCMAKE_INSTALL_DATAROOTDIR=%{_datadir} \
    -DCMAKE_INSTALL_MANDIR=%{_mandir} \
    -DCMAKE_INSTALL_LOCALSTATEDIR=%{_localstatedir} \
    -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
    -DINSTALL_UNITDIR=%{_unitdir} \
    -DRELEASE=ON \
    -DRPM_BUILD=ON
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_sbindir}
rm -f %{buildroot}%{_datadir}/doc/ipmctl/ipmctl_default.conf
rm -f %{buildroot}%{_datadir}/doc/ipmctl/LICENSE
rm -f %{buildroot}%{_datadir}/doc/ipmctl/thirdpartynotice.txt
rm -f %{buildroot}%{_datadir}/doc/ipmctl/edk2_License.txt
install -m 444 -p "%{SOURCE1}" .

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc README.md
%doc opensource
%doc Documentation/ipmctl/*
%doc ChangeLog.xz
%{_bindir}/%{name}
%{_mandir}/man1/*

#files data
%doc output/release/%{name}_default.conf
%config %{_sysconfdir}/%{name}.conf
%config %{_sysconfdir}/logrotate.d/%{name}
%dir %{_localstatedir}/log/%{name}

#files -n lib%%{name}%%{abi}
%{_libdir}/lib%{name}.so.%{abi}*

%files devel
%defattr(-,root,root)
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_includedir}/nvm_types.h
%{_includedir}/nvm_management.h
%{_includedir}/export_api.h
%{_includedir}/NvmSharedDefs.h

%changelog
* Thu Feb 22 2024 dimstar@opensuse.org
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Oct 31 2022 dimstar@opensuse.org
- Update to version 03.00.00.0468:
  + Connect namespace controllers during re-enumeration.
  + Set default value of PcdInvalid to False.
  + Fix memory resources info error.
  + Remove call MemoryResources function to reload namespace
    information.
  + Correct link removal behavior for preferences file.
  + Correct multiple NVM API behavior deficiencies.
  + Make ipmctl more resilient to unhealthy PMem modules.
  + Don't always create a preferences file in current directory.
  + Reduce ipmctl version firmware calls to only minimum necessary.
  + Check pointer for NULL before using to prevent seg fault.
* Mon Jan 17 2022 rw@suse.com
- Update to version 03.00.00.0423
  - Add support for newer systems.  [bsc#1194354]
  (For detailed changes see 'ChangeLog.xz')
- Refresh patch(es)
  (ipmctl-static-EDK2.patch.xz)
* Fri Dec 17 2021 rw@suse.com
- Update to version 03.00.00.0407
  - Use recommended version.  [jsc#SLE-18904, jsc#SLE-19429]
  (For detailed changes see 'ChangeLog.xz')
- Incorporate TianoCore EDK II build requirement as patch.
  (ipmctl-static-EDK2.patch.xz)
- Drop obsoleted patch(es).
  (ipmctl-python3.patch)
* Tue Feb  9 2021 rw@suse.com
- Update to version 02.00.00.3847  [jsc#SLE-12711]
  (For detailed changes see 'ChangeLog.xz')
* Fri Dec 11 2020 rw@suse.com
- Update to version 02.00.00.3833
  - Fix create goal command.  [bsc#1174807]
  (For detailed changes see 'ChangeLog.xz')
* Tue Mar 10 2020 rw@suse.com
- Update to version 02.00.00.3733
  - Add support for newer systems.  [bsc#1162844]
  (For detailed changes see 'ChangeLog.xz')
* Wed Feb 26 2020 rw@suse.com
- Fix creation (and packaging) of man-pages.  [bsc#1158619]
- Improve spec-file for upcoming update.
* Tue Feb 18 2020 rw@suse.com
- Update to version 01.00.00.3497
  - Try to avoid freezing on newer systems.  [bsc#1162935]
  (For detailed changes see 'ChangeLog.xz')
* Mon Feb  3 2020 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Dec 13 2019 rw@suse.com
- Update to version 01.00.00.3474
  - Use recommended version.  [jsc#SLE-7948]
  (For detailed changes see 'ChangeLog.xz')
* Wed Mar 13 2019 rw@suse.com
- Update to version v01.00.00.3440.
  - Support more than 16 sockets.  [FATE#327556, FATE#327573, bsc#1123735]
  - Fix flashing FW of DCPMM modules. [bsc#1128830, bsc#1134253, FATE#327773]
  (For detailed changes see 'ChangeLog.xz')
- Update SafeC dependency (as used in 3440).
- Refresh patch(es)
  (ipmctl-python3.patch)
* Tue Jan 29 2019 rw@suse.com
- Update to v01.00.00.3402.
  Switch to release tarball, no content changes.
- Improve spec-file.
* Mon Jan 21 2019 rw@suse.com
- Update to v01.00.00.3394+.  [FATE#326756, FATE#326917, FATE#326918]
  [bsc#1116404, bsc#1091108]
  Mandatory for current hard- and firmware.
  (For detailed changes see 'ChangeLog.xz')
- Integrate SafeC dependency in contrib.
- Fix remaining unconditional calls to python/python2.  [bsc#1111020]
  (ipmctl-python3.patch)
- Drop obsoleted patch(es).
  (ipmctl-fix-SLE12-build.patch)
* Wed Oct 17 2018 rw@suse.com
- Improve ipmctl-fix-SLE12-build.patch to produce position
  independent executables.
* Wed Oct 10 2018 rw@suse.com
- Remove hard build dependency on python2.  [bsc#1111020]
* Fri Aug 10 2018 rw@suse.com
- Update to v01.00.00.3102.  [FATE#325527]
  (Last release without "SafeC" dependency.)
- Refresh ipmctl-fix-SLE12-build.patch.
- Incorporate spec-file improvements proposed by mpluskal.
* Sun Jul 29 2018 jengelh@inai.de
- Add bullets to what is a bullet list in the description.
* Fri Jun 22 2018 rw@suse.com
- Fix build failure on SLE12-SP4.  [FATE#325527]
  (ipmctl-fix-SLE12-build.patch)
* Fri Jun  8 2018 juston.li@intel.com
- Release v01.00.00.3091
* Fri Jun  1 2018 juston.li@intel.com
- Release v01.00.00.3083
* Wed May 30 2018 juston.li@intel.com
- Initial release v01.00.00.3072
